require 'test_helper'
require 'fakefs/safe'

class RailsLogtruncateTest < ActiveSupport::TestCase
  def setup
    FakeFS.activate!
    File.write('test_file', "1" * 900)
    @logtruncate = RailsLogtruncate
    @logtruncate.truncator = RailsLogtruncate::Truncator.new
  end

  def teardown
    FakeFS.deactivate!
  end

  test "truncates logfile to 0 bytes if it exceedes quota" do
    assert_difference 'File.size("test_file")', -900 do
      @logtruncate.truncate('test_file', 800, 'test')
    end
  end

  test "does not truncate logfile if it does not exceed quota" do
    assert_difference 'File.size("test_file")', 0 do
      @logtruncate.truncate('test_file', 9_000, 'test')
    end
  end

  test "does not perform truncation if quota is set to 0" do
    assert_difference 'File.size("test_file")', 0 do
      @logtruncate.truncate('test_file', 0, 'test')
    end
  end

  test "does not perform truncation in production" do
    assert_difference 'File.size("test_file")', 0 do
      @logtruncate.truncate('test_file', 10, 'production')
    end
  end

  test "does perform truncation in development" do
    assert_difference 'File.size("test_file")', -900 do
      @logtruncate.truncate('test_file', 10, 'development')
    end
  end

  test "does not perform truncation if quota is not valid integer" do
    assert_difference 'File.size("test_file")', 0 do
      @logtruncate.truncate('test_file', nil, 'development')
    end
  end
end
